# New in 0.14.1 (2021-10-11)

Minor hotfixes.

## Changes

-   Filter out mitochrondrial genes as a preprocessing step in the Amortized LDA tutorial ([#1213])
-   Remove `verbose=True` argument from early stopping callback ([#1216])

## Contributors

-   [@adamgayoso]
-   [@jjhong922]
-   [@watiss]

[#1213]: https://github.com/YosefLab/scvi-tools/pull/1213
[#1216]: https://github.com/YosefLab/scvi-tools/pull/1216
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
[@watiss]: https://github.com/watiss
